@@ -1,4 +1,3 @@
-context("test-test-sagatools")
 library(Rsagacmd)
 library(magrittr)
 library(raster)
@@ -23,7 +22,7 @@ testthat::test_that("basic SAGA-GIS tool usage ", {
 
     # table output
     orb <- saga$climate_tools$earths_orbital_parameters()
-    testthat::expect_is(orb, "data.frame")
+    testthat::expect_is(orb, "tbl_df")
 
     # optional outputs with conditions on inputs
     flowacc <- dem %>%
@@ -46,28 +45,6 @@ testthat::test_that("basic SAGA-GIS tool usage ", {
 })
 
 
-testthat::test_that("tile geoprocessor function", {
-  testthat::skip_on_cran()
-
-  if (!is.null(saga_search())) {
-    saga <- saga_gis()
-
-    dem <- saga$grid_calculus$random_terrain(
-      target_user_xmin = 0,
-      target_user_xmax = 1000,
-      target_user_ymin = 0,
-      target_user_ymax = 1000,
-      radius = 100,
-      iterations = 500
-    )
-
-    tiles <- tile_geoprocessor(saga, dem, nx = 100, ny = 100)
-    testthat::expect_length(tiles, 100)
-    testthat::expect_is(tiles[[1]], "RasterLayer")
-  }
-})
-
-
 testthat::test_that("handling of single and multiband rasters", {
   testthat::skip_on_cran()
 
